#ifndef BOT_UTIL_H
#define BOT_UTIL_H

#include <dpp/dpp.h>
#include <mariadb/conncpp.hpp>
#include <regex>

class util {
public:
    /**
     * @brief The type of embed
     */
    enum EmbedType {ERROR,SUCCESS,INFO};

    /**
     * @brief Gets the hex color of an embed type
     * @param type The type of embed
     * @return The hex color
     */
    static uint32_t getHexColor(EmbedType type = INFO);

    /**
     * @brief Gets the default embed
     * @return The default embed
     */
    static dpp::embed getDefaultEmbed(EmbedType type = INFO);

    /**
     * @brief Sends a success message
     * @param event The event
     * @param message The message
     */
    static void sendSuccess(const dpp::slashcommand_t& event, const std::string& message);

    /**
     * @brief Sends an error message
     * @param event The event
     * @param message The message
     */
    static void sendError(const dpp::slashcommand_t& event, const std::string& message);

    /**
     * @brief Creates a connection to the database
     * @param config The database config
     * @return The connection
     */
    static sql::Connection* createConnection(const json& config);

    /**
     * @brief Gets a result set from a query
     * @param con The connection
     * @param query The query
     * @param params The parameters
     * @return The result set
     */
    static sql::ResultSet* getResultSet(sql::Connection& con, const std::string& query, std::initializer_list<std::string> params);

    /**
     * @brief Executes a query
     * @param con The connection
     * @param query The query
     * @param params The parameters
     */
    static void executeQuery(sql::Connection& con, const std::string& query, std::initializer_list<std::string> params);
};


#endif //BOT_UTIL_H
